@@ -92,6 +92,14 @@ char * cfgfile_get_app_thumbnails_path  (void);
  */
 char * cfgfile_get_image_info_path     (void);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get directory with cached queries.
+ *
+ * @return String with cached queries directory.
+ *         After use it should be freed using free.
+ */
+char * cfgfile_get_query_path (void);
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get path for default config file with window manager info.
  *
