@@ -307,4 +307,72 @@ urldata_search_pixbay (const char *s_query,
     return ud_data;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Search Wallhaven for images.
+ */
+UrlData *
+urldata_search_wallhaven (const char *s_query,
+                          const char *s_api_key,
+                          const int   i_page,
+                          const int   i_per_page)
+{
+    UrlData  *ud_data = NULL;
+    //char     *s_api   = NULL;
+    char     *s_url   = NULL;
+    char      s_page[64];
+    char      s_per_page[64];
+    CURL     *curl;
+    CURLcode  res;
+    struct curl_slist *list = NULL;
+
+    ud_data = urldata_new ();
+    curl_global_init (CURL_GLOBAL_ALL);
+    curl = curl_easy_init ();
+//https://wallhaven.cc/search?q=nature&categories=111&purity=110&sorting=relevance&order=desc&per_page=6&page=1
+    if (curl) {
+        sprintf (s_page, "%d", i_page);
+        sprintf (s_per_page, "%d", i_per_page);
+        //s_api = str_comb ("Authorization: ", s_api_key);
+        s_url = str_comb ("https://wallhaven.cc/api/v1/search?apikey=",
+                          s_api_key);
+        str_append (&s_url, "&q=");
+        str_append (&s_url, s_query);
+        //s_url = str_comb ("https://api.pexels.com/v1/search?query=", s_query);
+        str_append (&s_url, "&page=");
+        str_append (&s_url, s_page);
+        //str_append (&s_url, "&per_page=");
+        //str_append (&s_url, s_per_page);
+        str_append (&s_url, "&sorting=relevance");
+
+        //list = curl_slist_append (list, s_api);
+
+        curl_easy_setopt (curl, CURLOPT_URL, s_url);
+        //curl_easy_setopt (curl, CURLOPT_HTTPHEADER, list);
+        curl_easy_setopt (curl, CURLOPT_WRITEDATA, (void *) ud_data);
+        curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, url_write);
+#ifdef DEBUG
+        curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
+#endif
+ 
+        res = curl_easy_perform (curl);
+ 
+        if (res != CURLE_OK) {
+            ud_data->errbuf = malloc (CURL_ERROR_SIZE * sizeof (char));
+            if (ud_data->errbuf == NULL)
+                err (EXIT_FAILURE, NULL);
+
+            snprintf (ud_data->errbuf, CURL_ERROR_SIZE, "%s",
+                      curl_easy_strerror (res));
+            fprintf(stderr, "curl failed: %s\n", ud_data->errbuf);
+        }
+        curl_slist_free_all (list);
+ 
+        curl_easy_cleanup (curl);
+        //free (s_api);
+    }
+    curl_global_cleanup ();
+
+    return ud_data;
+}
+/*----------------------------------------------------------------------------*/
  
