@@ -242,7 +242,7 @@ add_searchitem_to_img_view (GtkWidget        *gw_iconview,
                            WEB_COL_PIXBUF,    gp_pbuf,
                            WEB_COL_WIDTH,     si_item->i_width,
                            WEB_COL_HEIGHT,    si_item->i_height,
-                           WEB_COL_ID,        si_item->i_id,
+                           WEB_COL_ID,        si_item->s_id,
                            WEB_COL_DISP_NAME, si_item->s_display_name,
                            WEB_COL_AUTHOR,    si_item->s_author_name,
                            WEB_COL_MARKUP,    si_item->s_display_markup,
